//
//  AGGradient.h
//  Created by Seth Willits on 6/30/07.
//  Copyright 2007 Araelium Group. All rights reserved.
//
//  ---
//
//  Based on CTGradient 1.6
//  Created by Chad Weider on 2/14/07.
//  Copyright (c) 2007 Chad Weider.
//  Some rights reserved: <http://creativecommons.org/licenses/by/2.5/>
//

#import <Cocoa/Cocoa.h>


typedef struct _AGGradientElement {
	CGFloat red, green, blue, alpha;
	CGFloat location;
	
	struct _AGGradientElement *nextElement;
} AGGradientElement;


typedef enum  _AGBlendingMode {
	AGLinearBlendingMode,
	AGChromaticBlendingMode,
	AGInverseChromaticBlendingMode
} AGGradientBlendingMode;


@interface AGGradient : NSObject <NSCopying>
{
	AGGradientElement * elementList;
	AGGradientBlendingMode blendingMode;
	CGFunctionRef gradientFunction;
}

+ (id)gradientWithStartingColor:(NSColor *)startingColor endingColor:(NSColor *)endingColor;
- (id)initWithStartingColor:(NSColor *)startingColor endingColor:(NSColor *)endingColor;
//- (id)initWithColors:(NSArray *)colorArray;
//- (id)initWithColorsAndLocations:(NSColor *)firstColor, ...;
//- (id)initWithColors:(NSArray *)colorArray atLocations:(const CGFloat *)locations colorSpace:(NSColorSpace *)colorSpace;


// DRAWING LINEAR GRADIENTS
//- (void)drawFromPoint:(NSPoint)startingPoint toPoint:(NSPoint)endingPoint options:(NSGradientDrawingOptions)options;
- (void)drawInRect:(NSRect)rect angle:(CGFloat)angle;
- (void)drawInBezierPath:(NSBezierPath *)path angle:(CGFloat)angle;


// DRAWING RADIAL GRADIENTS
//- (void)drawFromCenter:(NSPoint)startCenter radius:(CGFloat)startRadius toCenter:(NSPoint)endCenter radius:(CGFloat)endRadius options:(NSGradientDrawingOptions)options;
- (void)drawInRect:(NSRect)rect relativeCenterPosition:(NSPoint)relativeCenterPosition;
//- (void)drawInBezierPath:(NSBezierPath *)path relativeCenterPosition:(NSPoint)relativeCenterPosition;


// These methods are primarily for the use of controls which manipulate the color gradient.
//- (NSColorSpace *)colorSpace;
- (NSInteger)numberOfColorStops;
- (void)getColor:(NSColor **)color location:(CGFloat *)location atIndex:(NSInteger)index;
//- (NSColor *)interpolatedColorAtLocation:(CGFloat)location;



@end



//
//typedef NSUInteger NSGradientDrawingOptions;
//
//enum {
//    NSGradientDrawsBeforeStartingLocation =   (1 << 0),
//    NSGradientDrawsAfterEndingLocation =    (1 << 1),
//};
//
//
//@interface NSGradient : NSObject <NSCopying, NSCoding> {
//@private
//    NSArray *_colorArray;
//    NSColorSpace *_colorSpace;
//    __strong void *_functionRef;
//    void *_componentArray;
//}
//
//
//


@interface AGGradient (TableViewGradientsAdditions)

+ (AGGradient *)activeGradientForTigerMailSidebar;
+ (AGGradient *)inactiveGradientForTigerMailSidebar;

+ (AGGradient *)activeGradientForTigerFinderSidebar;
+ (AGGradient *)inactiveGradientForTigerFinderSidebar;

+ (AGGradient *)activeGradientForLeopardFinderSidebar;
+ (AGGradient *)inactiveGradientForLeopardFinderSidebar;

+ (AGGradient *)graphiteGradient;
+ (AGGradient *)darkGraphiteGradient;

@end

